@@ -1,14 +1,21 @@
 # plots data as radial lines or a polygon on a 24 hour "clockface" going 
 # clockwise. clock.pos should be in decimal hours between 0 and 24.
-# Remember to convert hour/minute values to hour/decimal values.
+# use hm2dec=TRUE to convert hour/minute values to hour/decimal values.
 # example: clock24.plot(rnorm(16)+3,seq(5.5,20.5,length.out=16))
 
 clock24.plot<-function(lengths,clock.pos,labels=0:23,minutes=FALSE,
- label.pos=NULL,rp.type="r",...) {
+ hm2dec=FALSE,label.pos=NULL,rp.type="r",...) {
  
  npos<-length(lengths)
  # if no positions are given, spread the lines out over the circle 
  if(missing(clock.pos)) clock.pos<-seq(0,24-24/(npos+1),length=npos)
+ else {
+  if(hm2dec) {
+   splittime<-strsplit(clock.pos,":")
+   hm2dh<-function(x) return(as.numeric(x[1])+as.numeric(x[2])/60)
+   clock.pos<-sapply(splittime,hm2dh)
+  }
+ }
  # start at "midnight" and go clockwise
  radial.pos<-pi*(clock.pos*15)/180
  if(minutes) labels<-paste(labels,"00",sep=":")
@@ -74,10 +81,7 @@ radial.plot<-function(lengths,radial.pos=NULL,labels=NA,label.pos=NULL,
  if(is.null(radial.pos.dim))
   radial.pos<-matrix(rep(radial.pos,nsets),nrow=nsets,byrow=TRUE)
  else radial.pos<-as.matrix(radial.pos)
- if(rp.type == "l") {
-  clockwise<-TRUE
-  start<-pi/2
- }
+ if(rp.type == "l" && clockwise == TRUE) start<-pi/2
  if(clockwise) radial.pos<--radial.pos
  if(start) radial.pos<-radial.pos+start
  if(show.grid) {
@@ -107,8 +111,9 @@ radial.plot<-function(lengths,radial.pos=NULL,labels=NA,label.pos=NULL,
   if(show.grid) {
    radial.grid(labels=labels,label.pos=label.pos,radlab=radlab,
     radial.lim=radial.lim,start=start,clockwise=clockwise,
-    label.prop=label.prop,grid.pos=grid.pos,grid.col=grid.col,
-    grid.bg=grid.bg,show.radial.grid=show.radial.grid)
+    label.prop=label.prop,grid.pos=grid.pos,rad.col=rad.col,
+    grid.col=grid.col,grid.bg=grid.bg,
+    show.radial.grid=show.radial.grid)
   }
  }
  par(xpd=TRUE)
@@ -156,6 +161,11 @@ radial.plot<-function(lengths,radial.pos=NULL,labels=NA,label.pos=NULL,
     lwd=lwidth,...)
   if(match("s",rptype,0))
    points(xpos,ypos,pch=pointsymbols,col=pointcol,...)
+  if(match("t",rptype,0)) {
+   if(boxed.radial)
+    boxed.labels(xpos,ypos,point.symbols,col=pointcol)
+   else text(xpos,ypos,point.symbols,col=pointcol)
+  }
   if(match("l",rptype,0))
    lines(xpos,ypos,lty=ltype,lwd=lwidth,col=linecol,...)
   if(show.centroid) {
